// ChatApplet - user interface for ACME Chat
//
// Copyright (C) 1996 by Jef Poskanzer <jef@acme.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit the ACME Labs Java page for up-to-date versions of this and other
// fine Java utilities: http://www.acme.com/java/

package Acme.Chat;

import java.applet.*;
import java.awt.*;
import java.awt.image.*;
import java.io.*;
import java.net.*;
import java.util.*;
import Acme.Widgets.*;

/// User interface for ACME Chat.
// <P>
// <A HREF="/resources/classes/Acme/Chat/ChatApplet.java">Fetch the software.</A><BR>
// <A HREF="/resources/classes/Acme.tar.Z">Fetch the entire Acme package.</A>

public class ChatApplet extends Applet implements Runnable
    {

    /// Applet info.
    public String getAppletInfo()
        {
        return getClass().getName() +
 " - Copyright (C) 1996 by Jef Poskanzer <jef@acme.com>.  All rights reserved.";
        }


    // A random number generator.
    Random random = new Random();

    // Our identifier.  Chance of collision is one in nine quintillion.
    long id = random.nextLong();

    // We append a unique sequence number to URLs each time we access them,
    // to make absolutely sure that caches don't fuck with us.
    long sequence = random.nextLong();


    private URL servletURL;

    Frame frame;
    Font font;
    private TextArea textArea;
    private int columns = -1;
    private static final int FUCKED_COLUMNS = 66;
    String name;
    private Label nameLabel;
    private TextField typeinField;

    /// Called when the applet is first created.
    public void init()
        {
	Acme.GuiUtils.handleBgcolor( this );
	frame = (Frame) Acme.GuiUtils.getTopParent( this );

	// Make the URL for talking to the servlet.
	try
	    {
	    servletURL = new URL( getCodeBase(), "/servlet/ChatServlet" );
	    }
	catch ( MalformedURLException e )
	    {
	    ErrorBox box = new ErrorBox( frame, e.toString() );
	    box.show();
	    return;
	    }

	// Make the GUI.

	font = new Font( "Courier", Font.PLAIN, 12 );
	setFont( font );

	GridBagLayout gb = new GridBagLayout();
	setLayout( gb );
	GridBagConstraints gbc = new GridBagConstraints();
	gbc.gridwidth = GridBagConstraints.REMAINDER;
	gbc.weightx = gbc.weighty = 1.0;

	textArea = new TextArea();
	textArea.setEditable( false );
	gbc.fill = GridBagConstraints.BOTH;
	gb.setConstraints( textArea, gbc );
	add( textArea );

	Panel typeinPanel = new Panel();
	GridBagLayout gb2 = new GridBagLayout();
	typeinPanel.setLayout( gb2 );
	GridBagConstraints gbc2 = new GridBagConstraints();

	String xxx = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
	nameLabel = new Label(
	    xxx.substring( 0, ChatUtils.NAME_MAX + 1 ), Label.RIGHT );
	gbc2.gridwidth = GridBagConstraints.RELATIVE;
	gbc2.fill = GridBagConstraints.NONE;
	gbc2.weightx = 0.0;
	gb2.setConstraints( nameLabel, gbc2 );
	typeinPanel.add( nameLabel );

	typeinField = new TextField();
	gbc2.gridwidth = GridBagConstraints.REMAINDER;
	gbc2.fill = GridBagConstraints.HORIZONTAL;
	gbc2.weightx = 1.0;
	gb2.setConstraints( typeinField, gbc2 );
	typeinPanel.add( typeinField );

	gbc.fill = GridBagConstraints.HORIZONTAL;
	gbc.weighty = 0.0;
	gb.setConstraints( typeinPanel, gbc );
	add( typeinPanel );

	Panel buttonPanel = new Panel();
	buttonPanel.setLayout( new FlowLayout( FlowLayout.LEFT ) );
	buttonPanel.add( new Button( "Name" ) );
	buttonPanel.add( new Button( "Who" ) );
	gbc.fill = GridBagConstraints.NONE;
	gbc.anchor = GridBagConstraints.CENTER;
	gb.setConstraints( buttonPanel, gbc );
	add( buttonPanel );

	validate();

	changeName( "anon" );
        }


    private Thread thread = null;

    /// Called when the applet should start itself.
    public void start()
        {
	if ( thread == null )
	    {
	    // Start the thread.
	    thread = new Thread( this );
	    thread.start();
	    }
	try
	    {
	    notIdle();
	    sendCommand( ChatUtils.CMD_CONNECT, null );
	    }
	catch ( IOException ignore ) {}
        }

    /// Called when the applet should stop itself.
    public void stop()
        {
	try
	    {
	    sendCommand( ChatUtils.CMD_DISCONNECT, null );
	    }
	catch ( IOException ignore ) {}
	if ( thread != null )
	    {
	    // Stop the thread.
	    thread.stop();
	    thread = null;
	    }
        }


    /// Event handler.
    public boolean handleEvent( Event evt )
	{
	switch ( evt.id )
	    {
	    case Event.ACTION_EVENT:
	    if ( evt.arg.equals( "Name" ) )
		{
		name();
		return true;
		}
	    if ( evt.arg.equals( "Who" ) )
		{
		who();
		return true;
		}
	    break;
	    case Event.KEY_PRESS:
	    if ( evt.target == typeinField && evt.key == 10 )
		{
		line();
		return true;
		}
	    break;
	    }
	return super.handleEvent( evt );
	}

    private void name()
	{
	notIdle();
	new ChatAppletNameThread( this );
	}

    void changeName( String name )
	{
	this.name = name;
	nameLabel.setText( name + ":" );
	}

    private void who()
	{
	notIdle();
	new ChatAppletWhoThread( this );
	}

    private void line()
	{
	String text = typeinField.getText();
	typeinField.setText( "" );
	if ( text == null || text.length() == 0 )
	    return;
	try
	    {
	    notIdle();
	    sendCommand( ChatUtils.CMD_NEW_LINE, text );
	    }
	catch ( IOException e )
	    {
	    ErrorBox box = new ErrorBox( frame, e.toString() );
	    box.show();
	    }
	}


    /// Method from Runnable.
    public void run()
	{
	int conseqErrs = 0;
	Thread me = Thread.currentThread();
	while ( thread == me )
	    {
	    // Pause a bit.
	    try
		{
		Thread.sleep( 1000 );
		}
	    catch ( InterruptedException ignore ) {}

	    // Get a line from the chat servlet.
	    try
		{
		String content = sendRequest( ChatUtils.REQ_GET_LINE );
		String command = ChatUtils.getCommand( content );
		String data = ChatUtils.getData( content );
		if ( command == null )
		    throw new IOException( "bogus response from server" );
		else if ( command.equals( ChatUtils.RES_OK ) )
		    addLine( data.trim() );
		else if ( command.equals( ChatUtils.RES_NOTHING ) )
		    {/*ignore*/}
		else if ( command.equals( ChatUtils.RES_ERROR ) )
		    throw new IOException( "error response from server" );
		else
		    throw new IOException( "unknown response from server" );
		}
	    catch ( IOException e )
		{
		ErrorBox box = new ErrorBox( frame, e.toString() );
		box.show();
		if ( ++conseqErrs > 5 )
		    {
		    thread = null;
		    break;
		    }
		continue;
		}
	    conseqErrs = 0;
	    }
	}

    void addLines( String lines )
	{
	while ( lines.length() > 0 )
	    {
	    int nl = lines.indexOf( '\n' );
	    if ( nl == -1 )
		{
		addLine( lines );
		return;
		}
	    addLine( lines.substring( 0, nl ) );
	    lines = lines.substring( nl + 1 );
	    }
	}

    private static final long INT_BEEP = Acme.Utils.INT_MINUTE * 10;

    synchronized void addLine( String line )
	{
	if ( idle() >= INT_BEEP )
	    ( new Acme.SynthAudioClip( 440, 250 ) ).play();

	if ( columns == -1 )
	    //columns = textArea.getColumns();
	    // !!! getColumns() returns 0, which is useless, so we hack.
	    columns = FUCKED_COLUMNS;

	while ( line.length() > columns )
	    {
	    int bl = line.lastIndexOf( ' ', columns );
	    String thisLine;
	    if ( bl != -1 )
		{
		thisLine = line.substring( 0, bl );
		line = "  " + line.substring( bl + 1 ).trim();
		}
	    else
		{
		thisLine = line.substring( 0, columns );
		line = "  " + line.substring( columns ).trim();
		}
	    textArea.appendText( thisLine );
	    textArea.appendText( "\n" );
	    }
	textArea.appendText( line );
	textArea.appendText( "\n" );
	}


    /// Send a command, via POST.  No response.
    void sendCommand( String command, String data ) throws IOException
	{
	URL url = new URL(
	    servletURL, servletURL.getFile() +
	    "?" + ChatUtils.PRM_USERID + "=" + id +
	    "&" + ChatUtils.PRM_COMMAND + "=" + command +
	    "&" + ChatUtils.PRM_SEQUENCE + "=" + sequence++ );
	Acme.PostURLConnection uc = new Acme.PostURLConnection( url );
	uc.setDoOutput( true );
	uc.setUseCaches( false );
	if ( data == null )
	    {
	    uc.setRequestProperty( "Content-Length", Integer.toString( 0 ) );
	    OutputStream out = uc.getOutputStream();
	    out.close();
	    }
	else
	    {
	    int len = data.length();
	    uc.setRequestProperty( "Content-Length", Integer.toString( len ) );
	    OutputStream out = uc.getOutputStream();
	    byte[] bytes = new byte[len];
	    data.getBytes( 0, len, bytes, 0 );
	    out.write( bytes, 0, len );
	    out.flush();
	    out.close();
	    }
	}

    /// Send a request, via GET, and read back a response.
    String sendRequest( String request ) throws IOException
	{
	URL url = new URL(
	    servletURL, servletURL.getFile() +
	    "?" + ChatUtils.PRM_USERID + "=" + id +
	    "&" + ChatUtils.PRM_COMMAND + "=" + request +
	    "&" + ChatUtils.PRM_SEQUENCE + "=" + sequence++ );
	URLConnection uc = url.openConnection();
	uc.setUseCaches( false );
	uc.connect();
	int len = uc.getContentLength();
	if ( len == -1 )
	    return "";
	InputStream in = uc.getInputStream();
	byte[] bytes = new byte[len];
	if ( Acme.Utils.readFully( in, bytes, 0, len ) == -1 )
	    throw new IOException( "incomplete response" );
	in.close();
	return new String( bytes, 0, 0, len );
	}


    private long lastActive = System.currentTimeMillis();

    private long idle()
	{
	long now = System.currentTimeMillis();
	long idle = now - lastActive;
	lastActive = now;
	return idle;
	}

    private void notIdle()
	{
	lastActive = System.currentTimeMillis();
	}



    /// Main program, so we can run as an application too.
    public static void main( String[] args )
        {
        new Acme.MainFrame( new ChatApplet(), args, 500, 400 );
        }

    }


class ChatAppletNameThread extends Thread
    {
    private ChatApplet chatApplet;
    public ChatAppletNameThread( ChatApplet chatApplet )
	{
	this.chatApplet = chatApplet;
	start();
	}
    public void run()
	{
	ChatAppletName chatAppletName =
	    new ChatAppletName( chatApplet, chatApplet.frame );
	chatAppletName.show();
	}
    }


class ChatAppletName extends Dialog
    {

    private ChatApplet chatApplet;
    private Frame frame;
    private TextField nameField;

    public ChatAppletName( ChatApplet chatApplet, Frame frame )
	{
	super( frame, "Name", false );
	this.chatApplet = chatApplet;
	this.frame = frame;
	setFont( chatApplet.font );
	setResizable( false );
	setBackground( Acme.GuiUtils.qmarkColor );

	GridBagLayout gb = new GridBagLayout();
	setLayout( gb );
	GridBagConstraints gbc = new GridBagConstraints();
	gbc.insets = new Insets( 5, 5, 5, 5 );

	ImageLabel imageLabel = new ImageLabel( Acme.GuiUtils.qmarkIcon( this ) );
	gb.setConstraints( imageLabel, gbc );
	add( imageLabel );
	Label label = new Label( "New name:" );
	gb.setConstraints( label, gbc );
	add( label );
	nameField = new TextField( ChatUtils.NAME_MAX );
	gbc.gridwidth = GridBagConstraints.REMAINDER;
	gb.setConstraints( nameField, gbc );
	add( nameField );

	Panel buttonPanel = new Panel();
	buttonPanel.setLayout( new FlowLayout( FlowLayout.LEFT ) );
	buttonPanel.add( new Button( "Ok" ) );
	buttonPanel.add( new Button( "Cancel" ) );
	gb.setConstraints( buttonPanel, gbc );
	add( buttonPanel );

	if ( chatApplet.name != null )
	    nameField.setText( chatApplet.name );
	}

    public void show()
	{
	pack();
	validate();
	super.show();
	}

    /// Event handler.
    public boolean handleEvent( Event evt )
	{
	switch ( evt.id )
	    {
	    case Event.ACTION_EVENT:
	    if ( evt.arg.equals( "Ok" ) )
		{
		click( nameField.getText() );
		return true;
		}
	    else if ( evt.arg.equals( "Cancel" ) )
		{
		click( null );
		return true;
		}
	    break;
	    case Event.KEY_PRESS:
	    if ( evt.target == nameField && evt.key == 10 )
		{
		click( nameField.getText() );
		return true;
		}
	    break;
	    }
	return super.handleEvent( evt );
	}

    private void click( String val )
	{
	if ( val != null )
	    {
	    val = val.trim();
	    if ( val.length() == 0 )
		{
		WarningBox box =
		    new WarningBox( frame, "Please specify a name." );
		box.show();
		return;
		}
	    if ( val.length() > ChatUtils.NAME_MAX )
		{
		WarningBox box = new WarningBox( frame,
		    "Only " + ChatUtils.NAME_MAX + " characters allowed." );
		box.show();
		return;
		}
	    try
		{
		chatApplet.sendCommand( ChatUtils.CMD_NEW_NAME, val );
		}
	    catch ( IOException e )
		{
		ErrorBox box = new ErrorBox( frame, e.toString() );
		box.show();
		}
	    chatApplet.changeName( val );
	    }
	hide();
	dispose();
	}

    }


class ChatAppletWhoThread extends Thread
    {
    private ChatApplet chatApplet;
    public ChatAppletWhoThread( ChatApplet chatApplet )
	{
	this.chatApplet = chatApplet;
	start();
	}
    public void run()
	{
	try
	    {
	    String content = chatApplet.sendRequest( ChatUtils.REQ_WHOS_ON );
	    String command = ChatUtils.getCommand( content );
	    String data = ChatUtils.getData( content );
	    if ( command == null )
		throw new IOException( "bogus response from server" );
	    else if ( command.equals( ChatUtils.RES_OK ) )
		chatApplet.addLines( "Who's on:\n" + data );
	    else if ( command.equals( ChatUtils.RES_NOTHING ) )
		{/*ignore*/}
	    else if ( command.equals( ChatUtils.RES_ERROR ) )
		throw new IOException( "error response from server" );
	    else
		throw new IOException( "unknown response from server" );
	    }
	catch ( IOException e )
	    {
	    ErrorBox box = new ErrorBox( chatApplet.frame, e.toString() );
	    box.show();
	    }
	}
    }
