// ChatUtils - utilities for ACME Chat
//
// Copyright (C) 1996 by Jef Poskanzer <jef@acme.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit the ACME Labs Java page for up-to-date versions of this and other
// fine Java utilities: http://www.acme.com/java/

package Acme.Chat;

import java.util.*;
import Acme.Serve.servlet.*;
import Acme.Serve.servlet.http.*;

/// Utilities for ACME Chat.
// <P>
// <A HREF="/resources/classes/Acme/Chat/ChatUtils.java">Fetch the software.</A><BR>
// <A HREF="/resources/classes/Acme.tar.Z">Fetch the entire Acme package.</A>

public class ChatUtils
    {

    /// Maximum length of a pseud.
    public static final int NAME_MAX = 12;

    /// Number of lines to store in the server.
    public static final int NUM_LINES = 1000;

    /// Milliseconds each get-line command is allowed to wait.
    public static final long INT_TIMEOUT = 5L * Acme.Utils.INT_MINUTE;

    /// Milliseconds of idle time until a user is considered disconnected.
    public static final long INT_IDLE = Acme.Utils.INT_HOUR;


    // Parameter names.
    public static final String PRM_USERID = "ID";
    public static final String PRM_COMMAND = "CM";
    public static final String PRM_SEQUENCE = "SQ";

    // Commands.
    public static final String CMD_CONNECT = "CO";
    public static final String CMD_NEW_NAME = "NN";
    public static final String CMD_NEW_LINE = "NL";
    public static final String CMD_DISCONNECT = "DC";

    // Requests (commands that generate a response).
    public static final String REQ_GET_LINE = "GL";
    public static final String REQ_WHOS_ON = "WH";

    // Responses (commands sent back to the client).
    public static final String RES_OK = "OK";
    public static final String RES_NOTHING = "NO";
    public static final String RES_ERROR = "ER";


    /// Get the command/response part of a content string.
    public static String getCommand( String content )
	{
	int nl = content.indexOf( '\n' );
	if ( nl == -1 )
	    return null;
	return content.substring( 0, nl );
	}

    /// Get the data part of a content string.
    public static String getData( String content )
	{
	int nl = content.indexOf( '\n' );
	if ( nl == -1 )
	    return null;
	return content.substring( nl + 1 );
	}

    }
