// WebPost - post a web query and write the results to stdout
//
// Does a POST to a specified URL with given parameters and dumps
// the results to stdout.
//
// Copyright (C) 1997 by Jef Poskanzer <jef@acme.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit the ACME Labs Java page for up-to-date versions of this and other
// fine Java utilities: http://www.acme.com/java/

import java.net.*;
import java.io.*;

public class WebPost extends Acme.Application
    {

    static final String progName = "WebPost";

    // Old-style main() routine.  Calls compatibility routine for newMain().
    public static void main( String[] args )
        {
        (new WebPost()).compat( args );
        }

    public int newMain( String[] args )
	{
	int argc = args.length;
	if ( argc < 1 )
	    {
	    usage();
	    return -1;
	    }
	String urlStr = args[0];
	try
	    {
	    URL url = new URL( urlStr );
	    Acme.PostURLConnection uc = new Acme.PostURLConnection( url );
	    uc.setDoInput( true );
	    uc.setDoOutput( true );
	    // Make content string.
	    StringBuffer contentBuf = new StringBuffer();
	    for ( int argn = 1; argn < argc; ++argn )
		{
		if ( contentBuf.length() > 0 )
		    contentBuf.append( '&' );
		int eq = args[argn].indexOf( '=' );
		if ( eq == -1 )
		    contentBuf.append( URLEncoder.encode( args[argn] ) );
		else
		    {
		    contentBuf.append(
			URLEncoder.encode( args[argn].substring( 0, eq ) ) );
		    contentBuf.append( '=' );
		    contentBuf.append(
			URLEncoder.encode( args[argn].substring( eq + 1 ) ) );
		    }
		}
	    // Send query.
	    String contentStr = contentBuf.toString();
	    int len = contentStr.length();
	    byte[] contentBytes = new byte[len];
	    contentStr.getBytes( 0, len, contentBytes, 0 );
	    uc.setRequestProperty(
		"Content-length", Integer.toString( len ) );
	    uc.setRequestProperty(
		"Content-type", "application/x-www-form-urlencoded" );
	    uc.connect();
	    OutputStream os = uc.getOutputStream();
	    os.write( contentBytes );
	    os.flush();
	    // Read and show results.
	    InputStream is = uc.getInputStream();
	    byte[] buf = new byte[4096];
	    while ( ( len = is.read( buf ) ) != -1 )
		out.write( buf, 0, len );
	    // Done.
	    uc.close();
	    }
	catch ( Exception e )
	    {
	    err.println( progName + ": " + e );
	    }
	return 0;
	}

    private void usage()
	{
	err.println( "usage:  " + progName + " URL param=value ..." );
	}

    }
